@@ -2,24 +2,17 @@
 # -*- coding:utf-8 -*-
 # @Author: Jialiang Shi
 try:
-    from urllib.parse import quote
+    from urllib.parse import quote_plus
 except ImportError:
-    from urllib import quote
+    from urllib import quote_plus
 
 from gerrit.utils.models import BaseModel
 
 
-class Edit(BaseModel):
+class GerritChangeEdit(BaseModel):
     def __init__(self, **kwargs):
-        super(Edit, self).__init__(**kwargs)
-        self.attributes = [
-            "ref",
-            "base_revision",
-            "base_patch_set_number",
-            "commit",
-            "change",
-            "gerrit",
-        ]
+        super(GerritChangeEdit, self).__init__(**kwargs)
+        self.entity_name = "ref"
 
     def get_change_file_content(self, file):
         """
@@ -29,7 +22,7 @@ class Edit(BaseModel):
         :param file: the file path
         :return:
         """
-        endpoint = "/changes/%s/edit/%s" % (self.change, quote(file, safe=""))
+        endpoint = "/changes/%s/edit/%s" % (self.change, quote_plus(file))
         response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
         result = self.gerrit.decode_response(response)
         return result
@@ -41,7 +34,7 @@ class Edit(BaseModel):
         :param file: the file path
         :return:
         """
-        endpoint = "/changes/%s/edit/%s/meta" % (self.change, quote(file, safe=""))
+        endpoint = "/changes/%s/edit/%s/meta" % (self.change, quote_plus(file))
         response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
         result = self.gerrit.decode_response(response)
         return result
@@ -54,7 +47,7 @@ class Edit(BaseModel):
         :param file_content: the content of the file need to change
         :return:
         """
-        endpoint = "/changes/%s/edit/%s" % (self.change, quote(file, safe=""))
+        endpoint = "/changes/%s/edit/%s" % (self.change, quote_plus(file))
         base_url = self.gerrit.get_endpoint_url(endpoint)
         self.gerrit.requester.put(
             base_url, data=file_content, headers={"Content-Type": "plain/text"}
@@ -96,7 +89,7 @@ class Edit(BaseModel):
         :param file: Path to file to delete.
         :return:
         """
-        endpoint = "/changes/%s/edit/%s" % (self.change, quote(file, safe=""))
+        endpoint = "/changes/%s/edit/%s" % (self.change, quote_plus(file))
         self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
 
     def change_commit_message(self, input_):
@@ -109,7 +102,7 @@ class Edit(BaseModel):
                 "message": "New commit message\\n\\nChange-Id: I10394472cbd17dd12454f229e4f6de00b143a444"
             }
 
-            change = gerrit.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             edit = change.get_edit()
             edit.change_commit_message(input_)
 
@@ -145,7 +138,7 @@ class Edit(BaseModel):
                 "notify": "NONE"
             }
 
-            change = gerrit.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             edit = change.get_edit()
             edit.publish(input_)
 
