@@ -5,21 +5,9 @@
 from gerrit.utils.models import BaseModel
 
 
-class Comment(BaseModel):
+class GerritChangeRevisionComment(BaseModel):
     def __init__(self, **kwargs):
-        super(Comment, self).__init__(**kwargs)
-        self.attributes = [
-            "id",
-            "path",
-            "line",
-            "in_reply_to",
-            "message",
-            "updated",
-            "author",
-            "change",
-            "revision",
-            "gerrit",
-        ]
+        super(GerritChangeRevisionComment, self).__init__(**kwargs)
 
     def delete(self, input_=None):
         """
@@ -33,7 +21,7 @@ class Comment(BaseModel):
                 "reason": "contains confidential information"
             }
 
-            change = gerrit.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             revision = change.get_revision('3848807f587dbd3a7e61723bbfbf1ad13ad5a00a')
             comment = revision.comments.get("e167e775_e069567a")
             result = comment.delete(input_)
@@ -69,7 +57,7 @@ class Comment(BaseModel):
             return result
 
 
-class Comments(object):
+class GerritChangeRevisionComments(object):
     def __init__(self, change, revision, gerrit):
         self.change = change
         self.revision = revision
@@ -90,7 +78,7 @@ class Comments(object):
                 comment = item
                 comment.update({"path": key})
                 comments.append(comment)
-        return Comment.parse_list(
+        return GerritChangeRevisionComment.parse_list(
             comments, change=self.change, revision=self.revision, gerrit=self.gerrit
         )
 
@@ -108,6 +96,6 @@ class Comments(object):
         )
         response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
         result = self.gerrit.decode_response(response)
-        return Comment.parse(
+        return GerritChangeRevisionComment.parse(
             result, change=self.change, revision=self.revision, gerrit=self.gerrit
         )
